# Histo(n)gram

A little Rust crate to count the number of [n-gram](https://en.wikipedia.org/wiki/N-gram)s in a text.

## Future work
* Add python bindings

# License
Licensed under either of Apache License, Version 2.0 or MIT license at your option.

Unless you explicitly state otherwise, any contribution intentionally submitted by you, shall be
dual licensed as above, without any additional terms or conditions.
